@@ -1,3 +1,3 @@
 from fabtest.test import VirtualBoxTest, FabTest
-from fabtest.utils import fab
+from fabtest.utils import fab, FabricAbortException
 from fabtest.vbox import VirtualBox
